// postRoutes.js
const express = require("express");
const pool1 = require("../../db");
const bcrypt = require("bcrypt");
const jwt = require("jsonwebtoken");
const { RequireNotGuest } = require("../../middleware/auth");

const router = express.Router({ mergeParams: true });

router.post("/registerUser", registerUserHandler);
router.post("/verifyUser", verifyUserHandler);
router.post("/logoutUser", logoutUserHandler);
router.post("/updateAccessCode", RequireNotGuest, updateAccessCodeHandler);
router.post("/update_chuni_player_team", RequireNotGuest, updateChuniPlayerTeamHandler);
router.post("/create_keychip", RequireNotGuest, createKeychipHandler);
router.post(
  "/update_chuni_profile_player_team",
  RequireNotGuest,
  updateChuniProfilePlayerTeamHandler,
);
router.post("/update_chuni_item_duel", RequireNotGuest, updateChuniItemDuelHandler);
router.post("/update_chuni_item_mapchar", RequireNotGuest, updateChuniItemMapcharHandler);
router.post("/update_trophyid", RequireNotGuest, updateTrophyIdHandler);
router.post("/update_nameplateId", RequireNotGuest, updateNameplateIdHandler);
router.post("/updateAvatarCustomization", RequireNotGuest, updateAvatarCustomizationHandler);
router.post("/update_chuni_player_rivals", RequireNotGuest, updateChuniPlayerRivalsHandler);
router.post("/update_friendlist", RequireNotGuest, updateChuniFriendList);
router.post("/update_chuni_favorite_music", RequireNotGuest, updateChuniFavoriteMusic);

function registerUserHandler(req, res) {
  const { accessCode, username, password, email } = req.body;

  pool1.query(
    `SELECT aime_user.id, aime_user.username, aime_user.email, aime_user.password, aime_card.user 
    FROM aime_user 
    LEFT JOIN aime_card ON aime_user.id = aime_card.user
    WHERE aime_card.access_code = ?`,
    [accessCode],
    (err, rows) => {
      if (err) {
        console.error("Error finding user:", err);
        return res.status(500).json({ error: "Failed to find user" });
      }

      if (rows.length === 0) {
        return res.status(404).json({
          error:
            "Please play at least one credit before registering.",
        });
      }

      const existingUser = rows[0];
      if (existingUser.username || existingUser.email) {
        return res.status(409).json({
          error: "Cannot change username, email, or password by signing up.",
        });
      }

      const saltRounds = 10;
      bcrypt.hash(password, saltRounds, function(err, hashedPassword) {
        if (err) {
          console.error("Error hashing password:", err);
          return res.status(500).json({
            error: "Failed to hash password",
          });
        }

        registerUser(req, existingUser.id, username, hashedPassword, email, res);
      });
    },
  );
}
function registerUser(req, userId, username, password, email, res) {
  const query =
    "UPDATE aime_user SET username = ?, password = ?, email = ? WHERE id = ?";

  pool1.query(query, [username, password, email, userId], (err, result) => {
    if (err) {
      console.error("Error registering user:", err);
      return res.status(500).json({
        error: "Username or email is already in use by another player.",
      });
    }

    if (result.affectedRows === 0) {
      return res.status(404).json({ error: "User not found" });
    }

    // Fetch the version from chuni_profile_data
    pool1.query(
      "SELECT version FROM chuni_profile_data WHERE user = ? ORDER BY version DESC LIMIT 1",
      [userId],
      (versionError, versionResults) => {
        if (versionError) {
          console.error("Error fetching version:", versionError);
          return res.status(500).json({ error: "Error fetching version" });
        }

        if (versionResults.length === 0) {
          return res
            .status(500)
            .json({ error: "No version found for the user" });
        }

        const version = versionResults[0].version;

        // Check if the user already has a rival code
        pool1.query(
          "SELECT rival_code FROM cozynet_rival_codes WHERE id = ?",
          [userId],
          (rivalCodeError, rivalCodeResults) => {
            if (rivalCodeError) {
              console.error(
                "Error checking for existing rival code:",
                rivalCodeError,
              );
              return res
                .status(500)
                .json({ error: "Error checking for existing rival code" });
            }

            let rivalCode;

            if (rivalCodeResults.length > 0) {
              // Use the existing rival code
              rivalCode = rivalCodeResults[0].rival_code;
            } else {
              // Generate a new rival code
              rivalCode = generateRandomCode();
              // Insert into cozynet_rival_codes table
              const rivalCodeQuery =
                "INSERT INTO cozynet_rival_codes (id, rival_code) VALUES (?, ?)";
              pool1.query(
                rivalCodeQuery,
                [userId, rivalCode],
                (insertError) => {
                  if (insertError) {
                    console.error(
                      "Error inserting into cozynet_rival_codes:",
                      insertError,
                    );
                    return res.status(500).json({
                      error: "Error inserting into cozynet_rival_codes",
                    });
                  }

                  MountAuthCookie(req, userId, version, rivalCode);
                  res.json({ message: "User registered successfully" });
                },
              );
            }
          },
        );
      },
    );
  });
}

function generateRandomCode() {
  // Generate a random 8-digit code
  return Math.floor(10000000 + Math.random() * 90000000);
}
function verifyUserHandler(req, res) {
  const { username, password } = req.body;

  pool1.query(
    `SELECT aime_user.id, aime_user.password, aime_card.access_code 
     FROM aime_user 
     LEFT JOIN aime_card ON aime_user.id = aime_card.user 
     WHERE aime_user.username = ?`,
    [username],
    (err, rows) => {
      if (err) {
        console.error("Error verifying user:", err);
        return res.status(500).json({ error: "Internal server error." });
      }

      if (rows.length === 0) {
        return res.status(404).json({ error: "This username does not exist." });
      }

      bcrypt.compare(password, rows[0].password, function(err, result) {
        if (err) {
          console.error("Error comparing password:", err);
          return res.status(500).json({ error: "Internal server error." });
        }

        if (result) {
          // Fetch the version from chuni_profile_data
          pool1.query(
            "SELECT version FROM chuni_profile_data WHERE user = ? ORDER BY version DESC LIMIT 1",
            [rows[0].id],
            (versionError, versionResults) => {
              if (versionError) {
                console.error("Error fetching version:", versionError);
                return res
                  .status(500)
                  .json({ error: "Error fetching version" });
              }

              if (versionResults.length === 0) {
                return res
                  .status(500)
                  .json({ error: "No version found for the user" });
              }

              const version = versionResults[0].version;

              // Check if the user already has a rival code
              pool1.query(
                "SELECT rival_code FROM cozynet_rival_codes WHERE id = ?",
                [rows[0].id],
                (rivalCodeError, rivalCodeResults) => {
                  if (rivalCodeError) {
                    console.error(
                      "Error checking for existing rival code:",
                      rivalCodeError,
                    );
                    return res.status(500).json({
                      error: "Error checking for existing rival code",
                    });
                  }

                  let rivalCode;

                  if (rivalCodeResults.length > 0) {
                    // Use the existing rival code
                    rivalCode = rivalCodeResults[0].rival_code;
                  } else {
                    // Generate a new rival code
                    rivalCode = generateRandomCode();
                    // Insert into cozynet_rival_codes table
                    const rivalCodeQuery =
                      "INSERT INTO cozynet_rival_codes (id, rival_code) VALUES (?, ?)";
                    pool1.query(
                      rivalCodeQuery,
                      [rows[0].id, rivalCode],
                      (insertError) => {
                        if (insertError) {
                          console.error(
                            "Error inserting into cozynet_rival_codes:",
                            insertError,
                          );
                          return res.status(500).json({
                            error: "Error inserting into cozynet_rival_codes",
                          });
                        }
                      },
                    );
                  }

                  MountAuthCookie(req, rows[0].id, version, rivalCode);

                  res.json({ message: "User verified successfully" });
                },
              );
            },
          );
        } else {
          return res.status(403).json({ error: "Invalid password provided." });
        }
      });
    },
  );
}

function logoutUserHandler(req, res) {
  if (req.session.cozynet?.userId === undefined) {
    return res.status(409).json({
      success: false,
      message: "You are not logged in.",
    });
  }

  req.session.destroy(() => 0);

  return res.status(200).json({
    success: true,
    message: "Logged out.",
    body: {},
  })
}
// Assume you are using Express
function updateChuniPlayerTeamHandler(req, res) {
  const { teamName } = req.body;

  const insertQuery = `
    INSERT INTO chuni_profile_team (teamName)
    VALUES (?)
  `;

  pool1.query(insertQuery, [teamName], (error, results) => {
    if (error) {
      console.error("Error inserting team name:", error);
      return res.status(500).send("Error inserting team name");
    }

    // Fetch the updated list of teams from the database
    const selectQuery = `
      SELECT id, teamName FROM chuni_profile_team
    `;

    pool1.query(selectQuery, (selectError, selectResults) => {
      if (selectError) {
        console.error("Error fetching team names:", selectError);
        return res.status(500).send("Error fetching team names");
      }

      // Send the updated list of teams to the frontend
      res.json({
        success: true,
        message: "Team name inserted successfully",
        teams: selectResults,
      });
    });
  });
}

function createKeychipHandler(req, res) {
  const user = req.session.cozynet.userId;
  const allowedUsers = process.env.SYSOP_USER_IDS.split(",").map((e) => Number(e));

  if (!allowedUsers.includes(user)) {
    return res.status(401).send("You are not allowed to create a keychip.");
  }

  const { arcade_nickname, name, game, namcopcbid, serial } = req.body;

  const sqlValidateAccessCode = `
    SELECT aime_user.id 
    FROM aime_user
    JOIN aime_card ON aime_user.id = aime_card.user
    WHERE aime_card.user = ?`;

  pool1.query(sqlValidateAccessCode, [user], (error, results) => {
    if (error) {
      console.error("SQL error during access code validation:", error);
      return res.status(500).send("Error validating access code");
    }

    if (results.length === 0) {
      return res.status(400).send("Invalid access code");
    }

    const userId = results[0].id;

    const sqlInsertArcade = "INSERT INTO arcade (name, nickname) VALUES (?, ?)";
    console.log(
      "Creating new arcade entry with name:",
      name,
      "and nickname:",
      arcade_nickname,
    );
    pool1.query(sqlInsertArcade, [name, arcade_nickname], (error, results) => {
      if (error) {
        console.error("SQL error during arcade creation:", error);
        return res.status(500).send("Error creating arcade");
      }

      const sqlFetchArcadeId = "SELECT LAST_INSERT_ID() as id";
      console.log("Fetching new arcade ID...");
      pool1.query(sqlFetchArcadeId, (error, results) => {
        if (error) {
          console.error("SQL error during fetching new arcade ID:", error);
          return res.status(500).send("Error fetching new arcade ID");
        }

        const newArcadeId = results[0].id;

        const sqlAssignMachine =
          "INSERT INTO arcade_owner (user, arcade, permissions) VALUES (?, ?, ?)";
        console.log("Assigning arcade", newArcadeId, "to user", userId);
        pool1.query(
          sqlAssignMachine,
          [userId, newArcadeId, 1],
          (error, results) => {
            if (error) {
              console.error(
                "SQL error during assigning machine to user:",
                error,
              );
              return res.status(500).send("Error assigning machine to user");
            }

            const serialId = game === "SDEW" ? namcopcbid : serial;
            const sqlCreateMachine =
              "INSERT INTO machine (arcade, serial, game) VALUES (?, ?, ?)";
            console.log(
              "Creating machine with arcade ID:",
              newArcadeId,
              ", serial ID:",
              serialId,
              "and game:",
              game,
            );
            pool1.query(
              sqlCreateMachine,
              [newArcadeId, serialId, game],
              (error, results) => {
                if (error) {
                  console.error("SQL error during machine creation:", error);
                  return res.status(500).send("Error creating machine");
                }

                console.log(
                  "Machine created successfully. Arcade and machine created successfully.",
                );
                res.json({
                  success: true,
                  message: "Arcade and machine created successfully",
                });
              },
            );
          },
        );
      });
    });
  });
}

function updateChuniProfilePlayerTeamHandler(req, res) {
  const user = req.session.cozynet.userId;

  const { teamId } = req.body;

  const updateQuery = `
    UPDATE chuni_profile_data
    SET 
    teamId = ?
    WHERE user = (
      SELECT aime_user.id 
      FROM aime_user
      JOIN aime_card ON aime_user.id = aime_card.user
      WHERE aime_card.user = ?
    )`;

  pool1.query(updateQuery, [teamId, user], (error, results) => {
    if (error) {
      res.status(500).send("Error updating avatar customization");
      throw error;
    }

    res.json({
      success: true,
      message: "Avatar customization updated successfully",
    });
  });
}
function updateChuniItemDuelHandler(req, res) {
  const user = req.session.cozynet.userId;

  const { voiceId } = req.body;

  const updateQuery = `
    UPDATE chuni_profile_data
    SET 
      voiceId = ?
    WHERE user = (
      SELECT aime_user.id 
      FROM aime_user
      JOIN aime_card ON aime_user.id = aime_card.user
      WHERE aime_card.user = ?
    )`;

  pool1.query(updateQuery, [voiceId, user], (error, results) => {
    if (error) {
      res.status(500).send("Error updating avatar customization");
      throw error;
    }

    res.json({
      success: true,
      message: "Avatar customization updated successfully",
    });
  });
}

function updateChuniItemMapcharHandler(req, res) {
  const user = req.session.cozynet.userId;

  const { mapIconId } = req.body;

  const updateQuery = `
    UPDATE chuni_profile_data
    SET 
      mapIconId = ?
    WHERE user = (
      SELECT aime_user.id 
      FROM aime_user
      JOIN aime_card ON aime_user.id = aime_card.user
      WHERE aime_card.user = ?
    )`;

  pool1.query(updateQuery, [mapIconId, user], (error, results) => {
    if (error) {
      res.status(500).send("Error updating avatar customization");
      throw error;
    }

    res.json({
      success: true,
      message: "Avatar customization updated successfully",
    });
  });
}
function updateTrophyIdHandler(req, res) {
  const user = req.session.cozynet.userId;
  const { trophyId } = req.body;

  const updateQuery = `
    UPDATE chuni_profile_data
    SET 
      trophyId = ?
    WHERE user = (
      SELECT aime_user.id 
      FROM aime_user
      JOIN aime_card ON aime_user.id = aime_card.user
      WHERE aime_card.user = ?
    )`;

  pool1.query(updateQuery, [trophyId, user], (error, results) => {
    if (error) {
      console.error("Error updating trophyId:", error);
      return res.status(500).json({
        success: false,
        message: "Error updating trophyId",
      });
    }

    res.json({
      success: true,
      message: "TrophyId updated successfully",
    });
  });
}
function updateNameplateIdHandler(req, res) {
  const user = req.session.cozynet.userId;

  const { nameplateId } = req.body;

  const updateQuery = `
    UPDATE chuni_profile_data
    SET 
      nameplateId = ?
    WHERE user = (
      SELECT aime_user.id 
      FROM aime_user
      JOIN aime_card ON aime_user.id = aime_card.user
      WHERE aime_card.user = ?
    )`;

  pool1.query(updateQuery, [nameplateId, user], (error, results) => {
    if (error) {
      res.status(500).send("Error updating avatar customization");
      throw error;
    }

    res.json({
      success: true,
      message: "Avatar customization updated successfully",
    });
  });
}

function updateAvatarCustomizationHandler(req, res) {
  const user = req.session.cozynet.userId;

  const { avatarItem, avatarBack, avatarFace, avatarWear, avatarHead } =
    req.body;

  const updateQuery = `
    UPDATE chuni_profile_data
    SET 
      avatarItem = ?, 
      avatarBack = ?, 
      avatarFace = ?, 
      avatarWear = ?, 
      avatarHead = ?
    WHERE user = (
      SELECT aime_user.id 
      FROM aime_user
      JOIN aime_card ON aime_user.id = aime_card.user
      WHERE aime_card.user = ?
    )`;
  pool1.query(
    updateQuery,
    [avatarItem, avatarBack, avatarFace, avatarWear, avatarHead, user],
    (error, results) => {
      if (error) {
        console.error("Database Error:", error);
        res.status(500).send("Error updating avatar customization");
        console.log("Update Query:", updateQuery);
        console.log("Parameters:", [
          avatarItem,
          avatarBack,
          avatarFace,
          avatarWear,
          avatarHead,
          user,
        ]);
        throw error;
      }

      console.log("Update Query:", updateQuery);
      console.log("Parameters:", [
        avatarItem,
        avatarBack,
        avatarFace,
        avatarWear,
        avatarHead,
        user,
      ]);

      res.json({
        success: true,
        message: "Avatar customization updated successfully",
      });
    },
  );
}
function updateChuniFavoriteMusic(req, res) {
  // Assuming you have middleware to verify and decode the JWT and store user ID in req.user
  const { userId: user1, version } = req.session.cozynet;
  const songId = req.body.songId;

  // Check if the user has already added the specified musicId as a favorite
  const checkExistingFavoriteQuery = `
      SELECT COUNT(*) as existingCount
      FROM chuni_item_favorite
      WHERE user = ? AND version = ? AND favId = ? AND favKind = 1
    `;

  pool1.query(
    checkExistingFavoriteQuery,
    [user1, version, songId],
    (existingCountError, existingCountResults) => {
      if (existingCountError) {
        console.error(
          "Error checking existing favorite for user:",
          existingCountError,
        );
        return res.status(500).send("Error checking existing favorite");
      }

      const existingFavoriteCount = existingCountResults[0].existingCount;

      // If the user has already added the specified musicId as a favorite, return an error
      if (existingFavoriteCount > 0) {
        return res.status(400).json({
          success: false,
          message: "User has already added this songId as a favorite.",
        });
      }

      // Check the current count of favorites for user1
      const checkCountQuery = `
        SELECT COUNT(*) as favCount
        FROM chuni_item_favorite
        WHERE user = ? AND version = ? AND favKind = 1
      `;

      pool1.query(
        checkCountQuery,
        [user1, version],
        (countError, countResults) => {
          if (countError) {
            console.error(
              "Error checking favorite count for user:",
              countError,
            );
            return res.status(500).send("Error checking favorite count");
          }

          const currentFavoriteCount = countResults[0].favCount;

          // Check if the user1 has reached the limit (e.g., 20)
          if (currentFavoriteCount >= 20) {
            return res.status(400).json({
              success: false,
              message:
                "User has reached the maximum limit of favorites (20). Cannot add more.",
            });
          }

          // If the limit is not reached and the musicId is not already a favorite, proceed with inserting favorite relation
          const insertQuery1 = `
          INSERT INTO chuni_item_favorite (user, version, favId, favKind)
          VALUES (?, ?, ?, 1)
        `;

          console.log("Inserting favorites. user1:", user1, "songId:", songId);
          pool1.query(
            insertQuery1,
            [user1, version, songId],
            (insertError1, results1) => {
              if (insertError1) {
                console.error(
                  "Error inserting favorite for user:",
                  insertError1,
                );
                return res.status(500).send("Error inserting favorite");
              }

              res.json({
                success: true,
                message: "Favorites inserted successfully",
              });
            },
          );
        },
      );
    },
  );
}

function updateChuniPlayerRivalsHandler(req, res) {
  // Assuming you have middleware to verify and decode the JWT and store user ID in req.user
  const { userId: user1, version } = req.session.cozynet;
  const rivalCode = req.body.rivalCode;

  // Check if user1 already has four rivals
  const countQuery1 = `
      SELECT COUNT(*) as rivalCount FROM chuni_item_favorite
      WHERE user = ? AND favKind = 2
    `;

  pool1.query(countQuery1, [user1], (countError1, countResults1) => {
    if (countError1) {
      console.error("Error counting rivals for user1:", countError1);
      return res.status(500).send("Error counting rivals");
    }

    const rivalCount1 = countResults1[0].rivalCount;

    if (rivalCount1 >= 4) {
      return res.status(400).json({
        success: false,
        message: "You already have four rivals. Unable to add more.",
      });
    }

    // Get user2's ID based on rivalCode
    const getUserIdByRivalCodeQuery = `
        SELECT id FROM cozynet_rival_codes
        WHERE rival_code = ?;
      `;

    pool1.query(getUserIdByRivalCodeQuery, [rivalCode], (error, results) => {
      if (error) {
        console.error("Error retrieving user id by rival code:", error);
        return res.status(500).send("Error retrieving user id by rival code");
      }

      if (!results || results.length === 0) {
        return res.status(404).json({
          success: false,
          message: "Rival code not found",
        });
      }

      const user2 = results[0].id;

      // Check if user2 already has four rivals
      const countQuery2 = `
          SELECT COUNT(*) as rivalCount FROM chuni_item_favorite
          WHERE user = ? AND favKind = 2
        `;

      pool1.query(countQuery2, [user2], (countError2, countResults2) => {
        if (countError2) {
          console.error("Error counting rivals for user2:", countError2);
          return res.status(500).send("Error counting rivals");
        }

        const rivalCount2 = countResults2[0].rivalCount;

        if (rivalCount2 >= 4) {
          return res.status(400).json({
            success: false,
            message:
              "The selected user already has four rivals. Unable to add more.",
          });
        }

        // If both users have fewer than four rivals, proceed with inserting rival relations
        const insertQuery1 = `
            INSERT INTO chuni_item_favorite (user, version, favId, favKind)
            VALUES (?, ?, ?, 2)
          `;

        const insertQuery2 = `
            INSERT INTO chuni_item_favorite (user, version, favId, favKind)
            VALUES (?, ?, ?, 2)
          `;

        console.log("Inserting favorites. user1:", user1, "user2:", user2);

        pool1.query(
          insertQuery1,
          [user1, version, user2],
          (insertError1, results1) => {
            if (insertError1) {
              console.error(
                "Error inserting favorite for user1:",
                insertError1,
              );
              return res.status(500).send("Error inserting favorite");
            }

            pool1.query(
              insertQuery2,
              [user2, version, user1],
              (insertError2, results2) => {
                if (insertError2) {
                  console.error(
                    "Error inserting favorite for user2:",
                    insertError2,
                  );
                  return res.status(500).send("Error inserting favorite");
                }

                res.json({
                  success: true,
                  message: "Favorites inserted successfully",
                });
              },
            );
          },
        );
      });
    });
  });
}

function updateChuniFriendList(req, res) {
  // Assuming you have middleware to verify and decode the JWT and store user ID in req.user
  const { user1, version, rivalCode } = req.body;

  // Get user2's ID based on rivalCode
  const getUserIdByRivalCodeQuery = `
  SELECT id FROM cozynet_rival_codes
  WHERE rival_code = ?;
`;

  pool1.query(getUserIdByRivalCodeQuery, [rivalCode], (error, results) => {
    if (error) {
      console.error("Error retrieving user id by rival code:", error);
      return res.status(500).send("Error retrieving user id by rival code");
    }

    if (!results || results.length === 0) {
      return res.status(404).json({
        success: false,
        message: "Rival code not found",
      });
    }

    const user2 = results[0].id;

    // If both users have no limit on rivals, proceed with inserting rival relations
    const insertQuery1 = `
    INSERT INTO chuni_item_favorite (user, version, favId, favKind)
    VALUES (?, ?, ?, 3)
  `;

    const insertQuery2 = `
    INSERT INTO chuni_item_favorite (user, version, favId, favKind)
    VALUES (?, ?, ?, 3)
  `;

    console.log("Inserting favorites. user1:", user1, "user2:", user2);

    pool1.query(
      insertQuery1,
      [user1, version, user2],
      (insertError1, results1) => {
        if (insertError1) {
          console.error("Error inserting favorite for user1:", insertError1);
          return res.status(500).send("Error inserting favorite");
        }

        pool1.query(
          insertQuery2,
          [user2, version, user1],
          (insertError2, results2) => {
            if (insertError2) {
              console.error(
                "Error inserting favorite for user2:",
                insertError2,
              );
              return res.status(500).send("Error inserting favorite");
            }

            res.json({
              success: true,
              message: "Favorites inserted successfully",
            });
          },
        );
      },
    );
  });
}
function updateAccessCodeHandler(req, res) {
  const { userId, version } = req.session.cozynet; // Get version from URL parameter
  const { access_code } = req.body;

  if (!version) {
    return res
      .status(400)
      .json({ error: "Version parameter is required" });
  }

  const updateQuery = `
      UPDATE aime_card ac
      JOIN chuni_profile_data pd ON ac.user = pd.user
      SET ac.access_code = ?
      WHERE ac.user = ? AND pd.version = ?;
    `;

  pool1.query(updateQuery, [access_code, userId, version], (error, results) => {
    if (error) {
      console.error("Error updating access code:", error);
      return res.status(500).json({
        success: false,
        message: "Error updating access code",
        error: error.message,
      });
    }

    // Check if any rows were affected
    if (results.affectedRows === 0) {
      return res.status(404).json({
        success: false,
        message: "User not found with the specified user ID and version",
      });
    }

    res.json({
      success: true,
      message: "Access code updated successfully",
    });
  });
}

module.exports = router;

function MountAuthCookie(req, userId, version, rivalCode) {
  req.session.cozynet = { userId, version, rivalCode };
  req.session.cookie.maxAge = 3.154e10;
} 
